// Add custom nextJs configurations.
// see https://nextjs.org/docs/api-reference/next.config.js/introduction for more details
// nodemon monitors this file for changes to restart server to make sure to keep this file in git
const { withModuleFederation } = require("@module-federation/nextjs-mf");
const path = require("path");

module.exports = {
  future: {
    webpack5: true,
  },
  webpack: (config, options) => {
    const name = "nextjs-webapp-template";
    const mfConf = {
      mergeRuntime: true,
      name,
      library: { type: config.output.libraryTarget, name },
      filename: "static/runtime/remoteEntry.js",
      remotes: {
        // For SSR, resolve to disk path (or you can use code streaming if you have access)
        [name]: options.isServer
          ? path.resolve(
              __dirname,
              `../${name}/.next/server/static/runtime/remoteEntry.js`
            )
          : name, // for client, treat it as a global
      },
      exposes: {
        "./StaticAssets": "./src/modules/StaticAssets/index",
      },
      shared: [],
    };

    // Configures ModuleFederation and other Webpack properties
    withModuleFederation(config, options, mfConf);
    // config.plugins.push(new MergeRuntime());

    if (!options.isServer) {
      config.output.publicPath = "http://localhost:3000/_next/";
    }

    // Important: return the modified config
    return config;
  },
};
